Examples of External Clients
---------------------------------------

These are examples of downloading data from data services like
FDSN and the Geomagnetic Observatory data supplied by the 
U.S. Geological Survey.

.. toctree::
    :maxdepth: 1

    ../examples/notebooks/make_mth5_driver_v0.1.0.ipynb
    ../examples/notebooks/make_mth5_driver_v0.2.0.ipynb
    ../examples/notebooks/make_mth5_from_geomag.ipynb
